// $Id$

package org.bolet.jgz.api;

import junit.framework.Test;
import junit.framework.TestCase;
import junit.framework.TestSuite;

import org.bolet.jgz.ZlibInputStream;
import org.bolet.jgz.ZlibOutputStream;

import java.io.ByteArrayInputStream;
import java.io.ByteArrayOutputStream;
import java.io.InputStream;
import java.io.IOException;
import java.util.Arrays;

/**
 * Unit tests for deflater / inflater processing (compatibility with self).
 *
 * @version   $Revision$
 * @author    Thomas Pornin
 */

public class TestSelf extends TestCase {

	public TestSelf(String name)
	{
		super(name);
	}

	public static Test suite()
	{
		return new TestSuite(TestSelf.class);
	}

	/* ============================================================ */

	private void self(InputStream in)
		throws IOException
	{
		byte[] data = Utils.readAll(in);
		self(data);
	}

	private void self(byte[] data)
		throws IOException
	{
		ByteArrayOutputStream baos = new ByteArrayOutputStream();
		ZlibOutputStream zout = new ZlibOutputStream(baos);
		zout.write(data);
		zout.terminate();
		byte[] zdata = baos.toByteArray();
		ByteArrayInputStream bais = new ByteArrayInputStream(zdata);
		ZlibInputStream zin = new ZlibInputStream(bais);
		byte[] data2 = Utils.readAll(zin);
		assertTrue(Arrays.equals(data, data2));

		/*
		if (data.length > 100)
			System.out.printf("%7d -> %7d   (%6.2f)\n",
				data.length, zdata.length, 100.0 *
				(double)zdata.length / (double)data.length);
		*/
	}

	private void selfRand(int len)
		throws IOException
	{
		byte[] data = new byte[len];
		Utils.PRNG.nextBytes(data);
		self(data);
	}

	private void selfZero(int len)
		throws IOException
	{
		byte[] data = new byte[len];
		self(data);
	}

	private void selfText(int len)
		throws IOException
	{
		byte[] data = Utils.makeRandText(len);
		self(data);
	}

	public void testRand()
		throws IOException
	{
		for (int i = 0; i < 100; i ++)
			selfRand(i);
		int len = 100;
		for (int i = 0; i < 12; i ++) {
			len *= 2;
			selfRand(len);
		}
	}

	public void testZero()
		throws IOException
	{
		for (int i = 0; i < 100; i ++)
			selfZero(i);
		int len = 100;
		for (int i = 0; i < 12; i ++) {
			len *= 2;
			selfZero(len);
		}
	}

	public void testText()
		throws IOException
	{
		for (int i = 0; i < 100; i ++)
			selfText(i);
		int len = 100;
		for (int i = 0; i < 12; i ++) {
			len *= 2;
			selfText(len);
		}
	}
}
