// $Id$

package org.bolet.jgz.api;

import java.io.ByteArrayOutputStream;
import java.io.InputStream;
import java.io.IOException;
import java.util.Random;

class Utils {

	static final Random PRNG = new Random(1);

	static byte[] readAll(InputStream in)
		throws IOException
	{
		ByteArrayOutputStream baos = new ByteArrayOutputStream();
		byte[] buf = new byte[8192];
		for (;;) {
			int rlen = in.read(buf);
			if (rlen < 0)
				break;
			baos.write(buf, 0, rlen);
		}
		return baos.toByteArray();
	}

	static byte[] makeRandText(int len)
	{
		StringBuilder sb = new StringBuilder();
		int lineLen = 0;
		boolean sentenceBegin = true;
		while (sb.length() < len) {
			int olen = sb.length();
			String word = WORDS[PRNG.nextInt(WORDS.length)];
			if (lineLen > 0)
				sb.append(' ');
			if (sentenceBegin == true) {
				sb.append((char)Character.toTitleCase(
					word.charAt(0)));
				sb.append(word.substring(1));
			} else {
				sb.append(word);
			}
			sentenceBegin = false;
			switch (PRNG.nextInt(50)) {
			case 0:
				sb.append('.');
				sentenceBegin = true;
				break;
			case 1:
			case 2:
				sb.append(',');
				break;
			case 3:
				sb.append(';');
				break;
			case 4:
				sb.append(':');
				break;
			case 5:
				sb.append('?');
				sentenceBegin = true;
				break;
			case 6:
				sb.append('!');
				sentenceBegin = true;
				break;
			}
			lineLen += sb.length() - olen;
			if (lineLen > 72) {
				sb.append('\n');
				lineLen = 0;
			}
		}
		byte[] res = new byte[len];
		for (int i = 0; i < len; i ++)
			res[i] = (byte)sb.charAt(i);
		return res;
	}

	/**
	 * Some French and English words.
	 */
	private static final String[] WORDS = {
		"a", "abbr", "abeille", "able", "about", "above",
		"abroad", "absent", "accept", "accepter", "accident",
		"acheter", "acier", "across", "acteur", "actor",
		"actrice", "actually", "addition", "address", "adieu",
		"adj", "adresse", "adult", "adulte", "adverb", "advice",
		"affaires", "affam\u00E9", "after", "afternoon",
		"afterwards", "again", "against", "age", "ago", "agree",
		"agr\u00E9able", "aide", "aider", "aigre", "aiguille",
		"aim", "aimer", "ainsi", "air", "airplane", "airport",
		"alarm", "alcohol", "alcool", "aliments", "all",
		"aller", "allow", "allumer", "almost", "alone",
		"alongside", "alors", "already", "also", "although",
		"always", "amer", "ami", "amie", "among", "amount",
		"amour", "amuse", "amuser", "am\u00E8re", "an", "and",
		"angry", "animal", "ankle", "anniversaire",
		"ann\u00E9e", "another", "answer", "ant", "ao\u00FBt",
		"appartement", "appeler", "appetite", "apple",
		"apporter", "apprendre", "app\u00E9tit", "apricot",
		"april", "apr\u00E8s", "apr\u00E8s-midi", "arbre",
		"argent", "arm", "armchair", "armoire", "army",
		"arm\u00E9e", "around", "arrival", "arrive", "arriver",
		"arriv\u00E9e", "arr\u00EAt", "arr\u00EAter", "art",
		"artist", "artiste", "as", "ascenseur", "aside", "ask",
		"aspirateur", "asseoir", "assez", "at", "attempt",
		"attendre", "attraper", "au", "au-dessous", "au-dessus",
		"august", "aujourd", "aunt", "aussi", "auteur",
		"author", "auto", "autobus", "automne", "automobile",
		"autour", "autre", "autumn", "avant", "avec", "average",
		"aveugle", "avion", "avoid", "avoir", "avril", "awake",
		"away", "a\u00E9roport", "baby", "back", "bacon", "bad",
		"badly", "bag", "bagage", "baggage", "bain", "baiser",
		"bake", "baker", "bakery", "balai", "balcon", "balcony",
		"ball", "ballon", "banana", "banane", "bank", "banque",
		"bar", "barbe", "barley", "bas", "basement", "basket",
		"bateau", "bath", "bathroom", "battre", "be", "beach",
		"bean", "bear", "beard", "beau", "beaucoup",
		"beautiful", "because", "become", "bed", "bedroom",
		"bee", "beef", "beefsteak", "beer", "before", "beg",
		"begin", "beginning", "behalf", "behind", "believe",
		"bell", "belle", "below", "belt", "besoin", "best",
		"bet", "better", "between", "beurre", "beverage",
		"bicycle", "bicyclette", "bien", "bient\u00F4t", "big",
		"bill", "billet", "bird", "birthday", "biscuit",
		"bitter", "bi\u00E8re", "black", "blanc", "blanche",
		"blanket", "blesser", "bleu", "blind", "blood",
		"blouse", "blue", "boat", "body", "boeuf", "boil",
		"boire", "bois", "boisson", "bol", "bon", "bone",
		"book", "bookshop", "boring", "both", "bottle",
		"bouche", "boucher", "bouger", "boulanger",
		"boulangerie", "bound", "bouteille", "bouton", "bowl",
		"box", "boy", "bo\u00EEte", "brain", "brake", "bras",
		"bread", "break", "breakfast", "breast", "bridge",
		"bring", "broom", "brosse", "brother", "brown", "bruit",
		"brun", "brush", "br\u00FBler", "building", "bureau",
		"burn", "bus", "business", "but", "butcher", "butter",
		"butterfly", "button", "buy", "by", "b\u00E9b\u00E9",
		"b\u00E9tail", "cabbage", "cadeau", "caf\u00E9",
		"caissier", "cake", "calculer", "calf", "call",
		"called", "camarade", "camion", "can", "canard",
		"candle", "capable", "car", "card", "careful",
		"carotte", "carpet", "carrot", "carry", "carte", "cas",
		"case", "cashier", "castle", "cat", "catch",
		"cathedral", "cath\u00E9drale", "cattle", "cauliflower",
		"cause", "cave", "ce", "ceinture", "cellar", "celui-ci",
		"celui-l\u00E0", "cent", "center", "centre", "century",
		"cerise", "certainly", "cerveau", "ces", "cet", "cette",
		"ceux", "chair", "chaise", "chambre", "chance",
		"chandelle", "change", "changement", "changer",
		"chanter", "chapeau", "chat", "chatte", "chaud",
		"chaussures", "cheap", "check", "cheek", "cheese",
		"chemin", "chemise", "cher", "chercher", "cherry",
		"chest", "cheval", "cheveux", "cheville", "chez-soi",
		"chicken", "chien", "child", "chin", "chocolat",
		"chocolate", "choisir", "choose", "chose", "chou",
		"chou-fleur", "christmas", "church", "ch\u00E2teau",
		"ch\u00E9re", "ch\u00EAne", "ciel", "cigarette", "cinq",
		"cinquante", "circa", "ciseaux", "citron", "city",
		"claim", "clair", "clean", "cleaner", "clear", "client",
		"cloche", "clock", "close", "clothes", "clou", "cloud",
		"cl\u00E9", "coat", "cochon", "coeur", "coffee", "coin",
		"col", "cold", "collar", "color", "comb", "come",
		"comme", "commencer", "comment", "compagnie", "company",
		"compare", "comparer", "comprendre", "comrade",
		"concombre", "conduire", "confiture", "conna\u00EEtre",
		"connection", "conseil", "consentir", "consider",
		"considerable", "consid\u00E9rable", "consid\u00E9rer",
		"content", "continue", "continuer", "contre",
		"convenant", "cook", "corbeille", "cord", "corde",
		"corner", "corps", "correct", "cost", "cot\u00E9",
		"cou", "coucher", "couch\u00E9", "coude", "couleur",
		"count", "country", "coup", "couper", "couple",
		"courir", "couronne", "courrier", "course", "cousin",
		"couteau", "couverture", "cow", "co\u00FBter",
		"cravate", "cream", "crime", "croire", "crown",
		"croyance", "cro\u00EEtre", "cry", "cr\u00E8me",
		"cucumber", "cueillir", "cuiller", "cuir", "cuire",
		"cuisine", "cuisinier", "cup", "cupboard", "curtain",
		"customs", "cut", "daddy", "dance", "danger",
		"dangereux", "dangerous", "dans", "danser", "dark",
		"date", "daughter", "davantage", "day", "de", "dead",
		"deaf", "dear", "debout", "december", "decide",
		"dedans", "deep", "degree", "degr\u00E9", "dehors",
		"demain", "demand", "demande", "demander", "dent",
		"dentist", "dentiste", "dents", "depart", "departure",
		"depuis", "dernier", "derni\u00E8re", "derri\u00E8re",
		"desert", "dessert", "dessiner", "deux",
		"deuxi\u00E8me", "devant", "devenir", "devoir",
		"dictionary", "dictionnaire", "die", "dieu",
		"different", "difficile", "difficult", "diff\u00E9rent",
		"dimanche", "diner", "dining", "dinner", "dire",
		"directement", "direction", "directly", "dirty",
		"disappointed", "discover", "disease", "distance",
		"dix", "dix-neuf", "dix-sept", "do", "doctor", "dog",
		"doigt", "donkey", "donner", "door", "dormir", "dos",
		"douane", "double", "douce", "doux", "douze", "down",
		"draw", "drawer", "dream", "dress", "drink", "drive",
		"droit", "droite", "drop", "drunk", "dry", "duck",
		"dur", "during", "dwel", "dwell", "dwelling",
		"d\u00E8s", "d\u00E9but", "d\u00E9cembre",
		"d\u00E9cider", "d\u00E9couvrir", "d\u00E9fendu",
		"d\u00E9ja", "d\u00E9jeuner", "d\u00E9part",
		"d\u00E9p\u00EAcher", "d\u00E9sert", "d\u00E9\u00E7u",
		"ear", "early", "earn", "earth", "east", "easy", "eat",
		"eau", "egg", "eight", "elbow", "elephant", "elevator",
		"eleven", "elle", "elles", "empty", "en", "encore",
		"end", "enemy", "enfant", "engine", "ennemi", "ennuis",
		"ennuyeux", "enough", "ensemble", "entendre", "enter",
		"entrance", "entre", "entrec\u00F4te", "entrer",
		"entr\u00E9e", "envelope", "enveloppe", "envie",
		"environ", "envoyer", "equal", "escalier", "essai",
		"essayer", "essence", "est", "est-ce", "et", "etc",
		"etc\u00E9tera", "even", "evening", "every",
		"everything", "everywhere", "evil", "ex-", "examiner",
		"example", "excellent", "except", "exchange", "exemple",
		"exit", "expensive", "explain", "expliquer", "extreme",
		"extr\u00EAme", "eye", "f", "face", "fach\u00E9",
		"fach\u00E9e", "facile", "factory", "faire", "fairly",
		"faith", "fall", "false", "famille", "family", "fancy",
		"far", "farine", "farm", "fast", "fat", "father",
		"fatigu\u00E9", "fault", "faute", "fauteuil", "faux",
		"fear", "february", "feel", "femme", "fen\u00EAtre",
		"fer", "ferme", "fetch", "feu", "few", "fifteen",
		"fifty", "fil", "fill", "fille", "fils", "fin",
		"finalement", "finally", "find", "fine", "finger",
		"finish", "fire", "firm", "first", "five", "flat",
		"fleur", "fleuve", "floor", "flour", "flower", "fly",
		"foi", "fois", "follow", "fontaine", "food", "for",
		"forbidden", "foreign", "forest", "forget", "forgive",
		"fork", "form", "forme", "fort", "forte", "fortune",
		"forty", "fountain", "four", "fourchette", "fourmi",
		"fourteen", "fox", "frais", "fraise", "free", "frein",
		"fresh", "friday", "friend", "frigidaire", "froid",
		"from", "fromage", "front", "fr\u00E8re", "full",
		"fumer", "funny", "furniture", "fusil", "futur",
		"future", "f\u00E9vrier", "f\u00EAte", "gagner", "gai",
		"game", "garden", "gare", "garer", "gar\u00E7on",
		"gasoline", "gauche", "genou", "gens", "get", "girl",
		"give", "glace", "glad", "gladly", "glass", "glasses",
		"go", "god", "gold", "gone", "good", "good-bye",
		"goose", "go\u00FBt", "grand", "grand-m\u00E8re",
		"grand-p\u00E8re", "grande", "grandfather",
		"grandmother", "gras", "grass", "gratuit", "gray",
		"green", "greetings", "gris", "ground", "grow", "gun",
		"g\u00E2teau", "habit", "habiter", "hair", "half",
		"ham", "hammer", "hand", "handbag", "handkerchief",
		"hang", "happy", "hard", "haricot", "hasty", "hat",
		"hate", "haut", "have", "he", "head", "health",
		"healthy", "hear", "heart", "heavy", "help", "her",
		"herbe", "here", "heure", "heureuse", "heureux", "hier",
		"high", "highway", "him", "his", "hit", "hiver", "hold",
		"hole", "holiday", "home", "homme", "horloge", "horse",
		"hospital", "hot", "hotel", "hour", "house", "how",
		"hui", "huile", "huit", "human", "hundred", "hungry",
		"hurry", "hurt", "husband", "h\u00F4pital",
		"h\u00F4tel", "i", "ice", "ici", "id\u00E9e", "if",
		"il", "ill", "ils", "image", "immediately", "impers",
		"important", "in", "inclination", "indeed",
		"infirmi\u00E8re", "informations", "injure", "inn",
		"insect", "inside", "instance", "instruire",
		"interessant", "interest", "interesting",
		"inter\u00EAt", "into", "invite", "inviter", "iron",
		"island", "it", "jacket", "jam", "jamais", "jambe",
		"jambon", "january", "janvier", "jardin", "jaune", "je",
		"jeter", "jeudi", "jeune", "jeune-fille", "joli",
		"joue", "jouer", "jour", "journal", "joyeux", "juice",
		"juillet", "juin", "july", "jump", "june", "jupe",
		"jus", "jusqu", "just", "keep", "key", "kind", "king",
		"kiss", "kitchen", "knee", "knife", "know", "knowledge",
		"l", "la", "lac", "ladder", "laid", "laine", "laisser",
		"lait", "lake", "lamp", "lampe", "land", "language",
		"langue", "lard", "large", "larme", "last", "late",
		"laugh", "laver", "lay", "le", "learn", "least",
		"leave", "left", "leg", "lemon", "lent", "les", "let",
		"letter", "lettre", "leur", "leurs", "lever",
		"librairie", "libre", "lie", "lies", "lieu", "life",
		"lift", "light", "like", "lip", "lire", "listen", "lit",
		"little", "live", "livre", "lointain", "long",
		"longtemps", "look", "lose", "loud", "lourd", "love",
		"low", "luck", "lui", "lumi\u00E8re", "lunch", "lundi",
		"lune", "lunettes", "l\u00E0", "l\u00E8vre",
		"l\u00E9ger", "l\u00E9gumes", "l\u00E9g\u00E8re", "m",
		"ma", "machine", "madame", "mademoiselle", "magasin",
		"magazine", "mai", "mail", "main", "maintenant", "mais",
		"maison", "make", "mal", "malade", "maladie",
		"malgr\u00E9", "man", "manage", "manger",
		"mani\u00E8re", "manner", "manteau", "manufacture",
		"many", "map", "march", "march\u00E9", "mardi", "mari",
		"mariage", "mari\u00E9", "mari\u00E9e", "marriage",
		"married", "mars", "marteau", "matin", "mauvais",
		"mauvaise", "maximum", "may", "ma\u00EEtre", "me",
		"meadow", "meal", "mean", "meanwhile", "meat", "meet",
		"meilleur", "meilleure", "memory", "mentir", "menton",
		"mer", "merci", "mercredi", "metal", "mettre",
		"meubles", "midday", "middle", "midi", "midnight",
		"mieux", "milk", "mille", "mince", "minuit", "minute",
		"miroir", "mirror", "miss", "mistake", "moi",
		"moi-m\u00EAme", "moins", "mois", "moiti\u00E9",
		"molle", "moment", "mon", "monday", "monde", "money",
		"monsieur", "montagne", "month", "montre", "montrer",
		"moon", "more", "morning", "mort", "most", "mot",
		"moteur", "mother", "mou", "mouche", "mouchoir",
		"mouill\u00E9", "mountain", "mourir", "mouse", "mouth",
		"mouvoir", "move", "moyen", "moyenne", "mr", "mrs",
		"much", "music", "must", "my", "mypleasure", "myself",
		"m\u00E8re", "m\u00E9chant", "m\u00E9decin",
		"m\u00E9moire", "m\u00E9tal", "m\u00E9tro", "m\u00EAme",
		"nager", "nail", "name", "napkin", "narrow", "nasty",
		"nature", "navire", "ne", "near", "neck", "need",
		"needle", "neige", "neighbor", "neither", "neuf",
		"never", "new", "news", "newspaper", "next", "nez",
		"ni", "nice", "night", "nine", "nineteen", "ninety",
		"no", "nobody", "noir", "noire", "noise", "noix", "nom",
		"nombre", "non", "noon", "nor", "nord", "north", "nos",
		"nose", "not", "note", "nothing", "notre", "noun",
		"nous", "nouveau", "nouvelle", "november", "novembre",
		"now", "nowhere", "no\u00EBl", "nuage", "nuit", "nulle",
		"number", "nurse", "nut", "oak", "object", "objects",
		"obscur", "october", "octobre", "odir", "oeil", "oeuf",
		"of", "off", "office", "often", "oie", "oignon", "oil",
		"oiseau", "old", "ombre", "on", "once", "oncle", "one",
		"oneself", "onion", "only", "onze", "open", "or",
		"orange", "ordinaire", "ordinary", "oreille", "orge",
		"orteil", "os", "other", "otherwise", "ou", "oublier",
		"ouest", "oui", "our", "ours", "outside", "ouvrir",
		"oven", "over", "overcoat", "own", "o\u00F9", "page",
		"pain", "pair", "pantalon", "papa", "paper", "papier",
		"papillon", "par", "parapluie", "parce", "pardonner",
		"pareil", "pareille", "pari", "parking", "parler",
		"parole", "part", "parti", "partie", "partiellement",
		"partir", "partly", "partout", "party", "pas",
		"passeport", "passport", "pass\u00E9", "past", "pauvre",
		"pay", "payer", "pays", "pea", "pear", "peau", "peigne",
		"peine", "pen", "pendant", "pendre", "penser", "people",
		"perdre", "perhaps", "permettre", "permit", "person",
		"personne", "petit", "peu", "peur", "peut-\u00EAtre",
		"pick", "picture", "piece", "pierre", "pig", "pince",
		"pi\u00E8ce", "place", "plage", "plat", "plate", "play",
		"pla\u00EEt", "pleasant", "please", "plein", "pleurer",
		"pleuvoir", "pluie", "plupart", "plur", "plural",
		"plus", "plut\u00F4t", "pneu", "poire", "pois",
		"poitrine", "pomme", "ponctuel", "pont", "poor", "porc",
		"pork", "porte", "porter", "poser", "possible", "post",
		"postale", "postcard", "poste", "pot", "potato",
		"pouce", "poulet", "pour", "pourquoi", "pousser",
		"pouvoir", "pray", "premier", "prendre", "present",
		"presque", "pretty", "price", "prier", "printemps",
		"prix", "probablement", "probably", "prochain",
		"proche", "profond", "promettre", "promise", "propos",
		"proposal", "proposition", "propre", "prudent", "prune",
		"pr\u00E9", "pr\u00EAt", "pull", "push", "put",
		"p\u00E8re", "p\u00E9ch\u00E9", "qu", "quand",
		"quarante", "quatorze", "quatre", "quatre-vingt-dix",
		"que", "queen", "quel", "quelle", "quelqu", "quelque",
		"quelques", "question", "qui", "quick", "quickly",
		"quiet", "quinze", "raconter", "radio", "rain",
		"raison", "randonner", "rare", "rarement", "raser",
		"rather", "reach", "read", "ready", "really", "reason",
		"receive", "recevoir", "red", "refrigerator",
		"regarder", "reine", "rejoindre", "rel", "remember",
		"remercier", "remplir", "remuer", "renard",
		"rencontrer", "repas", "repeat", "reposer", "rest",
		"restaurant", "retour", "revenir", "rice", "rich",
		"riche", "rideau", "rien", "right", "ring", "rire",
		"river", "riz", "road", "roi", "rompre", "rond", "roof",
		"room", "roue", "rouge", "round", "route", "rue", "run",
		"r\u00E9ponse", "r\u00E9p\u00E9ter",
		"r\u00E9veille-matin", "r\u00E9veiller", "r\u00EAve",
		"s", "sa", "sac", "sad", "sain", "salad", "salade",
		"sale", "salle", "salt", "same", "samedi", "sang",
		"sans", "sant\u00E9", "satisfied", "saturday",
		"saucisse", "sauf", "sausage", "sauter", "savoir",
		"savon", "say", "scarcely", "school", "science",
		"scissors", "screw", "se", "sea", "sec", "second",
		"see", "seem", "seize", "sel", "seldom", "sell",
		"semaine", "sembler", "send", "sentir", "sept",
		"september", "septembre", "serpent", "serve",
		"serviette", "servir", "ses", "seul", "seule",
		"seulement", "seven", "seventeen", "seventy", "shadow",
		"shave", "she", "ship", "shirt", "shoes", "shoot",
		"shoulder", "show", "si", "sick", "signifier",
		"signify", "silver", "similar", "simple", "sin",
		"since", "sing", "singular", "sinon", "sister", "sit",
		"six", "sixteen", "sixty", "si\u00E8cle", "sketch",
		"skin", "skirt", "sky", "sleep", "slow", "small",
		"smell", "smile", "smoke", "smooth", "snail", "snake",
		"snow", "so", "soap", "soeur", "soft", "soi-m\u00EAme",
		"soif", "soir", "soixante", "soixante-dix", "sol",
		"soleil", "solid", "solide", "some", "somebody",
		"sometimes", "somewhere", "son", "sonner", "sonnerie",
		"soon", "sorte", "sortie", "souhaiter", "soul",
		"souliers", "soup", "soupe", "souper", "sour", "sourd",
		"sourire", "souris", "sous", "south", "souvenir",
		"souvent", "speak", "spite", "splendid", "splendide",
		"spoon", "spot", "spring", "square", "stairs", "stamp",
		"stand", "star", "start", "station", "steel", "still",
		"stir", "stomach", "stone", "stop", "store", "storm",
		"stove", "straight", "strange", "strawberry", "street",
		"strike", "strong", "student", "study", "stylo", "such",
		"sucre", "sud", "suddenly", "sugar", "suit", "suitable",
		"suite", "suivre", "summer", "sun", "sunday", "supper",
		"sur", "sure", "sweet", "swim", "s\u00E8che",
		"s\u00FBr", "table", "take", "talk", "tall", "tante",
		"tapis", "tard", "task", "tasse", "taste", "te", "tea",
		"teach", "teacher", "tear", "tel", "telephone", "tell",
		"temps", "temp\u00EAte", "ten", "tenir", "terminer",
		"terre", "than", "thank", "that", "the", "their",
		"then", "there", "therefore", "these", "they", "thick",
		"thin", "thing", "think", "thirst", "thirteen",
		"thirty", "this", "thought", "thousand", "thread",
		"three", "throat", "through", "throw", "thumb",
		"thunder", "thursday", "thus", "th\u00E9", "ticket",
		"tie", "tiger", "tigre", "till", "timbre-poste", "time",
		"times", "tire", "tired", "tirer", "tiroir", "to",
		"today", "toe", "together", "toi", "toilet", "toilette",
		"toit", "tomate", "tomato", "tomber", "tomorrow", "ton",
		"tongs", "tongue", "tonnerre", "too", "tooth",
		"toothbrush", "touch", "toucher", "toujours", "tour",
		"tous", "tout", "toute", "toutes", "tower", "town",
		"traduire", "train", "tranquille", "translate",
		"travail", "travailler", "travel", "travers", "tree",
		"treize", "trente", "trip", "triste", "trois", "trop",
		"trou", "trouble", "trousers", "trouver", "truck",
		"true", "try", "tr\u00E8s", "tu", "tuesday", "twelve",
		"twenty", "twice", "two", "t\u00E2che",
		"t\u00E9l\u00E9phone", "t\u00EAte", "t\u00F4t", "ugly",
		"umbrella", "un", "uncle", "under", "underground",
		"understand", "une", "until", "up", "us", "use",
		"utiliser", "vacances", "vache", "vacuum", "valid",
		"valide", "veal", "veau", "vegetable", "vendre",
		"vendredi", "venir", "vent", "verb", "vert", "very",
		"veston", "viande", "vide", "vie", "vieille", "vieux",
		"village", "ville", "vin", "vingt", "vis", "visage",
		"visit", "visiter", "vite", "vitre", "vivre", "voeux",
		"voir", "voisin", "voiture", "voler", "volontiers",
		"vos", "votre", "vouloir", "vous", "voyage", "voyager",
		"vrai", "vraie", "vra\u00EEment", "v\u00EAtement",
		"v\u00EAtements", "wait", "waiter", "walk", "wander",
		"want", "warm", "wash", "watch", "water", "way", "we",
		"wear", "weather", "wednesday", "week", "weep",
		"weight", "well", "west", "wet", "what", "wheel",
		"when", "where", "which", "while", "white", "who",
		"whole", "whom", "why", "wife", "wind", "window",
		"wine", "winter", "wish", "with", "without", "woman",
		"wonder", "wood", "wool", "word", "work", "world",
		"write", "wrong", "y", "year", "yellow", "yes",
		"yesterday", "yet", "yeux", "you", "young", "your",
		"zero", "z\u00E9ro", "\u00E0", "\u00E2ne", "\u00E7a",
		"\u00E9chelle", "\u00E9cole", "\u00E9couter",
		"\u00E9crire", "\u00E9difice", "\u00E9gale",
		"\u00E9glise", "\u00E9pais", "\u00E9paisse",
		"\u00E9paule", "\u00E9pouse", "\u00E9scargot",
		"\u00E9stomac", "\u00E9tage", "\u00E9toile",
		"\u00E9trange", "\u00E9tranger", "\u00E9troit",
		"\u00E9tudiant", "\u00E9tudiante", "\u00E9tudier",
		"\u00E9t\u00E9", "\u00E9viter", "\u00EAtre", "\u00EEle"
	};
}
